# @jupyterlab/cells

A JupyterLab package which provides an implementation of a Jupyter notebook cell.
These cells are used in both the [notebook](../notebook) and the [code console](../console).
The result of cell execution is shown in an output area,
which is implemented in [@jupyterlab/outputarea](../outputarea).
Markdown and raw cells can have attachments,
which is implemented in [@jupyterlab/attachments](../attachments).
